@@ -5,7 +5,7 @@ use warnings;
 use 5.0100;
 
 # ABSTRACT: OpenSMILES format reader and writer
-our $VERSION = '0.5.2'; # VERSION
+our $VERSION = '0.6.0'; # VERSION
 
 require Exporter;
 our @ISA = qw( Exporter );
@@ -68,6 +68,7 @@ sub is_chiral_tetrahedral($)
 {
     my( $what ) = @_;
     if( ref $what eq 'HASH' ) { # Single atom
+        # CAVEAT: will fail for allenal configurations of @/@@ in raw mode
         return $what->{chirality} && $what->{chirality} =~ /^@@?$/
     } else {                    # Graph representing moiety
         return any { is_chiral_tetrahedral( $_ ) } $what->vertices;
@@ -277,7 +278,7 @@ references:
     }
 
 Except for C<symbol>, C<class> and C<number>, all keys of hash are
-optional. Per OpenSMIILES specification, default values for C<hcount>
+optional. Per OpenSMILES specification, default values for C<hcount>
 and C<class> are 0.
 
 =head3 Bonds
@@ -288,6 +289,32 @@ orders other than single (C<->, which is also a default) are represented
 as values of edge attribute C<bond>. They correspond to the symbols used
 in OpenSMILES specification.
 
+=head2 Options
+
+C<parse> accepts the following options for key-value pairs in an
+anonymous hash for its second parameter:
+
+=over
+
+=item C<max_hydrogen_count_digits>
+
+In OpenSMILES specification the number of attached hydrogen atoms for
+atoms in square brackets is limited to 9. IUPAC SMILES+ has increased
+this number to 99. With the value of C<max_hydrogen_count_digits> the
+parser could be instructed to allow other than 1 digit for attached
+hydrogen count.
+
+=item C<raw>
+
+With C<raw> set to anything evaluating to false, the parser will not
+convert neither implicit nor explicit hydrogen atoms in square brackets
+to atom hashes of their own. Moreover, it will not attempt to unify the
+representations of chirality. It should be noted, though, that many of
+subroutines of Chemistry::OpenSMILES expect non-raw data structures,
+thus processing raw output may produce weird results.
+
+=back
+
 =head1 CAVEATS
 
 Element symbols in square brackets are not limited to the ones known to
